@@ -1,3 +1,4 @@
 """ Contains individual GUI components """
 from .entry_visualization import entry_table, task_chart
-from .timer import timer_display, number
+from .menu_settings import settings_menu
+from .timer import number, timer_display
